@@ -4,7 +4,7 @@ use strict;
 use Carp;
 
 use vars qw/$VERSION/;
-$VERSION = '0.9';
+$VERSION = '0.901';
 
 BEGIN {
 
@@ -23,14 +23,13 @@ BEGIN {
     }
 }
 
-# Tags that default to closed (<br /> versus <br></br>)
+# Tags that are closed (<br /> versus <br></br>)
 my @DEFAULT_CLOSED = qw( area base br col frame hr img input meta param );
 
-# Tags that get a trailing newline by default
+# Tags that get a trailing newline
 my @DEFAULT_NEWLINE = qw( html head body div p tr table );
 
 my %DEFAULT_AUTO = (
-    prefix => '',
     suffix => '',
     method => 'tag'
 );
@@ -51,22 +50,14 @@ my @UNPRINTABLE = qw(
 );
 
 sub new {
-    my $class = shift;
-    my $self = bless {}, $class;
-    $self->_initialize( @_ );
+    my $self = bless {}, shift;
+    $self->_set_auto( 'method', 'closed', @DEFAULT_CLOSED );
+    $self->_set_auto( 'suffix', "\n",     @DEFAULT_NEWLINE );
     return $self;
 }
 
-sub _initialize {
-    my $self = shift;
-    $self->set_closed( @DEFAULT_CLOSED );
-    $self->set_suffix( "\n", @DEFAULT_NEWLINE );
-}
-
 sub _set_auto {
-    my $self  = shift;
-    my $kind  = shift;
-    my $value = shift;
+    my ( $self, $kind, $value ) = @_;
 
     if ( defined $value ) {
         for ( @_ ) {
@@ -78,36 +69,14 @@ sub _set_auto {
     }
 }
 
-sub set_open {
-    my $self = shift;
-    $self->_set_auto( 'method', undef, @_ );
-}
-
-sub set_closed {
-    my $self = shift;
-    $self->_set_auto( 'method', 'closed', @_ );
-}
-
-sub set_prefix {
-    my $self   = shift;
-    my $prefix = shift;
-
-    $self->_set_auto( 'prefix', $prefix, @_ );
-}
-
-sub set_suffix {
-    my $self   = shift;
-    my $suffix = shift;
-
-    $self->_set_auto( 'suffix', $suffix, @_ );
-}
-
 sub _str {
     my $obj = shift;
     if ( my $ref = ref $obj ) {
+
         # Flatten array refs...
         return join '', @$obj
           if 'ARRAY' eq $ref;
+
         # ...stringify objects...
         my $str = eval { $obj->as_string };
         return $str unless $@;
@@ -119,15 +88,13 @@ sub _str {
 
 # URL encode a string
 sub url_encode {
-    my $self = shift;
-    my $str  = _str( shift );
+    my $str = _str( $_[1] );
     $str =~ s/([^A-Za-z0-9_])/$1 eq ' ' ? '+' : sprintf("%%%02x", ord($1))/eg;
     return $str;
 }
 
 sub url_decode {
-    my $self = shift;
-    my $str  = shift;
+    my $str = $_[1];
     $str =~ s/[+]/ /g;
     $str =~ s/%([0-9a-f]{2})/chr(hex($1))/eg;
     return $str;
@@ -144,24 +111,20 @@ sub query_encode {
 
 # (X)HTML entity encode a string
 sub entity_encode {
-    my $self = shift;
-    my $str  = _str( shift );
+    my $str = _str( $_[1] );
     $str =~ s/([<>&'"])/$ENT_MAP{$1}/eg;
     return $str;
 }
 
 sub _tag_value {
-    my $self = shift;
-    my $val  = shift;
+    my ( $self, $val ) = @_;
     return '' if ref $val;
     return '="' . $self->entity_encode( $val ) . '"';
 }
 
 sub validate_tag {
-    my $self = shift;
-    my ( $closed, $name, $attr ) = @_;
+
     # Do nothing. Subclass to throw an error for invalid tags
-    return;
 }
 
 sub _tag {
@@ -194,10 +157,12 @@ sub tag {
 
     for my $a ( @_ ) {
         if ( 'HASH' eq ref $a ) {
+
             # Merge into attributes
             %attr = ( %attr, %$a );
         }
         else {
+
             # Generate markup
             push @out,
               $self->_tag( 0, $name, \%attr )
@@ -218,22 +183,20 @@ sub closed { shift->_tag( 1, @_ ) }
 
 # Generate a closing (X)HTML tag
 sub close {
-    my $self = shift;
-    my $name = shift;
-    return "</$name>";
+    return "</$_[1]>";
 }
 
 sub auto_tag {
     my $self = shift;
     my $name = shift;
-    my ( $method, $pre, $post ) =
-      map { $self->{autotag}->{$_}->{$name} || $DEFAULT_AUTO{$_} }
-      ( 'method', 'prefix', 'suffix' );
-    my @out = map { $pre . $_ . $post } $self->$method( $name, @_ );
+    my ( $method, $post )
+      = map { $self->{autotag}->{$_}->{$name} || $DEFAULT_AUTO{$_} }
+      ( 'method', 'suffix' );
+    my @out = map { $_ . $post } $self->$method( $name, @_ );
     return wantarray ? @out : join '', @out;
 }
 
-# Minimal JSON encoder
+# Minimal JSON encoder. Provided here for completeness - it's useful when generating JS.
 sub json_encode {
     my $self = shift;
     my $obj  = shift;
@@ -277,7 +240,7 @@ HTML::Tiny - Lightweight, dependency free HTML/XML generation
 
 =head1 VERSION
 
-This document describes HTML::Tiny version 0.9
+This document describes HTML::Tiny version 0.901
 
 =head1 SYNOPSIS
 
@@ -533,44 +496,6 @@ for the tag. Used internally to implement the tag-named methods.
 
 =back
 
-=head2 Controlling auto_tag
-
-The format of tags generated by C<< auto_tag >> (i.e. tags created by a
-direct call to auto_tag or to one of the tag-named convenience methods)
-may be modified in a number of ways.
-
-Use C<< set_open >> / C<< set_closed >> to control whether the tags
-default to open (<br></br>) or closed (<br />).
-
-Use C<< set_prefix >> / C<< set_suffix >> to inject the specific string
-before / after each generated tag. Typically set_suffix is used to
-control which tags automatically have a newline appended after them.
-
-B<Note:> These settings I<only> affect tags generated by C<auto_tag> and
-the tag-named convenience methods. C<tag>, C<open>, C<close> and
-C<closed> provide a more primitive interface for tag creation which
-bypasses the auto-decoration stage.
-
-=over
-
-=item C<< set_open( $tagname, ... ) >>
-
-Specify a list of tags that will be generated in open form (<tag></tag>).
-
-=item C<< set_closed( $tagname, ... ) >>
-
-Specify a list of tags that will be generated in closed form (<tag />).
-
-=item C<< set_prefix( $prefix, $tagname, ... ) >>
-
-Set a prefix string to be added to the named tags.
-
-=item C<< set_suffix( $suffix, $tagname, ... ) >>
-
-Set a suffix string to be added to the named tags.
-
-=back
-
 =head2 Methods named after tags
 
 In addition to the methods described above C<< HTML::Tiny >> provides
@@ -596,9 +521,6 @@ So:
     print $h->img({ src => 'pic.jpg' });
                     # prints <img src="pic.jpg" />
 
-This default behaviour can be overridden by calling C<< set_open >> or
-C<< set_closed >> with a list of tag names.
-
 All other tag methods generate tags to wrap whatever content they
 are passed:
 
@@ -704,6 +626,8 @@ HTML::Tiny requires no configuration files or environment variables.
 
 By design HTML::Tiny has no non-core dependencies.
 
+To run the tests you will require Test::More.
+
 =head1 INCOMPATIBILITIES
 
 None reported.
